@@ -57,7 +57,7 @@
 #'
 #' }
 boot.mirt <- function(x, R = 100, boot.fun = NULL, technical = NULL, ...){
-    boot.draws <- function(orgdat, ind, boot.fun,
+    boot.draws <- function(orgdat, ind, boot.fun, invariance,
                            npars, constrain, parprior, model, itemtype, group,
                            class, LR, obj, DTF = NULL, technical, ...) {
         ngroup <- length(unique(group))
@@ -84,7 +84,7 @@ boot.mirt <- function(x, R = 100, boot.fun = NULL, technical = NULL, ...){
         } else {
             if(class == 'MultipleGroupClass'){
                 mod <- try(multipleGroup(data=dat, model=model, itemtype=itemtype, group=g,
-                                     constrain=constrain, parprior=parprior,
+                                     constrain=constrain, parprior=parprior, invariance=invariance,
                                      calcNull=FALSE, verbose=FALSE, technical=technical,
                                      method=x@Options$method, draws=1, SE=FALSE, ...))
             } else {
@@ -124,12 +124,15 @@ boot.mirt <- function(x, R = 100, boot.fun = NULL, technical = NULL, ...){
     model <- x@Model$model
     parprior <- x@Model$parprior
     constrain <- x@Model$constrain
+    customGroup <- extract.mirt(x, 'customGroup')
+    customItems <- extract.mirt(x, 'customItems')
     LR <- x@Model$lrPars
     if(length(parprior) == 0L) parprior <- NULL
     if(length(constrain) == 0L) constrain <- NULL
     structure <- mod2values(x)
     longpars <- structure$value
     npars <- sum(structure$est)
+    invariance <- extract.mirt(x, 'invariance')
     if(is.null(boot.fun)){
         boot.fun <- function(x){
             structure <- mod2values(x)
@@ -141,8 +144,9 @@ boot.mirt <- function(x, R = 100, boot.fun = NULL, technical = NULL, ...){
     if(is.null(technical)) technical <- list(parallel=FALSE)
     else technical$parallel <- FALSE
     if(requireNamespace("boot", quietly = TRUE)){
-      boots <- boot::boot(dat, boot.draws,
-                          R=R, npars=npars, constrain=constrain, class=class,
+      boots <- boot::boot(dat, boot.draws, R=R, npars=npars,
+                          constrain=constrain, class=class, invariance=invariance,
+                          customGroup=customGroup, customItems=customItems,
                           parprior=parprior, model=model, itemtype=itemtype, group=group, LR=LR,
                           obj=x, technical=technical, boot.fun=boot.fun, ...)
       boots$call <- match.call()
