@@ -51,12 +51,14 @@
 #'   \item{constrain}{a list of item parameter constraints to indicate which item parameters were equal
 #'     during estimation}
 #'   \item{Prior}{prior density distribution for the latent traits}
+#'   \item{thetaPosterior}{posterior distribution for latent traits when using EM algorithm}
 #'   \item{key}{if supplied, the data scoring key}
 #'   \item{nfact}{number of latent traits/factors}
 #'   \item{nitems}{number of items}
 #'   \item{ngroups}{number of groups}
 #'   \item{groupNames}{character vector of unique group names}
 #'   \item{group}{a character vector indicating the group membership}
+#'   \item{invariance}{a character vector indicating \code{invariance} input from \code{\link{multipleGroup}}}
 #'   \item{secondordertest}{a logical indicating whether the model passed the second-order test
 #'     based on the Hessian matrix. Indicates whether model is a potential local maximum solution}
 #'   \item{SEMconv}{logical; check whether the supplemented EM information matrix converged. Will be \code{NA}
@@ -148,6 +150,8 @@ extract.mirt <- function(x, what){
                   rowID = x@Data$rowID,
                   factorNames=x@Model$factorNames,
                   EMhistory=x@Internals$EMhistory,
+                  invariance=x@Model$invariance,
+                  thetaPosterior=x@Internals$thetaPosterior,
                   # undocumented
                   factorNames = x@Model$factorNames,
                   parprior = x@Model$parprior,
@@ -164,6 +168,8 @@ extract.mirt <- function(x, what){
                   nestpars=x@Model$nestpars,
                   prodlist=x@Model$prodlist,
                   completely_missing=x@Data$completely_missing,
+                  customGroup=x@Internals$customGroup,
+                  customItems=x@Internals$customItems,
                   stop(sprintf("Could not extract element \'%s\'", what), call.=FALSE))
         ret
 }
